#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2015. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os.path, sys

from java.lang import System
from com.ibm.bpe.api import UTCDate

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/admin/bpclib.py"))
__file__ = "deleteFederationIndexerLog.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       (-id <pkid> | -objectId <oid> |"
  print "        -eventAfterUTC <timestamp> | -eventAfterLocal <timestamp>)"
  print "        -eventBeforeUTC <timestamp> | -eventBeforeLocal <timestamp>)"
  print "       [-slice <slice size>]"
  print
  print "Delete entries in the indexer log table."
  print "With option 'id', only the entry with the given id is deleted."
  print "With option 'objectId', only entries belonging to this oid are deleted."
  print "With option 'eventAfter', only entries after the given time are deleted."
  print "With option 'eventBefore', only entries before the given time are deleted."
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
  print "If you specify only the year, month, and day, the hour, minutes, and seconds are set to 00:00:00."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print "  eventBefore:        <now>"
  print "  slice:              10000"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr = ""
clusterName = None
serverName = None
nodeName = localNode
pkid = ""
objectId = ""
eventBefore = normalizeTimeStamp( UTCDate().toXsdString(), 0, 1)
eventAfter = ""
rows = "0"
slice = "10000"

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
       argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-id"):
    i = i+1;
    if (i < argc):
      pkid = sys.argv[i]
    else:
      argerr = "Missing argument for '-id' parameter"
    #endElse
  elif (arg == "-objectId"):
    i = i+1;
    if (i < argc):
      objectId = sys.argv[i]
    else:
      argerr = "Missing argument for '-objectId' parameter"
    #endElse
  elif (arg == "-eventAfterUTC"):
    i = i+1;
    if (i < argc):
      eventAfter = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not eventAfter:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-eventAfterUTC' parameter"
    #endElse
  elif (arg == "-eventAfterLocal"):
    i = i+1;
    if (i < argc):
      eventAfter = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not eventAfter:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-eventAfterLocal' parameter"
    #endElse
  elif (arg == "-eventBeforeUTC"):
    i = i+1;
    if (i < argc):
      eventBefore = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not eventBefore:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-eventBeforeUTC' parameter"
    #endElse
  elif (arg == "-eventBeforeLocal"):
    i = i+1;
    if (i < argc):
      eventBefore = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not eventBefore:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-eventBeforeLocal' parameter"
    #endElse
  elif (arg == "-slice"):
    i = i+1;
    if (i < argc):
      slice = sys.argv[i]
    else:
      argerr = "Missing argument for '-slice' parameter"
    #endElse
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  #endif
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)
if scope.convertToCluster():
  print "Warning: '" + serverName + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME|ARCHIVE"):
  usage("Process Choreographer or Archive Manager is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

htmMBean = scope.lookupMBean("TaskManager")

if not htmMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print
  print "**********************************************************************"
  print "* Note: If there are many indexer log entries to be deleted, you may *"
  print "*       experience a timeout because the server does not finish its  *"
  print "*       work before the scripting client expires.                    *"
  print "*       Either choose the script parameters such that the timeout    *"
  print "*       is avoided or increase the scripting client's timeout value  *"
  print "*       (see the WebSphere InfoCenter for details).                  *"
  print "**********************************************************************"
  print
  params = [ pkid, objectId, eventAfter, eventBefore, slice ]
  print "Deleting indexer log rows with [" + ", ".join(params) + "]..."
  print
  total = 0
  rows = 1
  try:
    while (rows > 0):
      rows = 0
      rows = int(AdminControl.invoke(htmMBean, "deleteIndexerLog", params ))
      total = total + rows
      if (total == 0 or rows > 0):
        now = normalizeTimeStamp( UTCDate().toXsdString(), 0, 1)
        print "%s UTC: %10d entries deleted." % (now, total)
      #endIf
    #endWhile
  except:
    print sys.exc_info()[0]
    print sys.exc_info()[1]
    if sys.exc_info()[2]:
      tb=sys.exc_info()[2]
      print tb.dumpStack()
    #endIf
  print
  print "Done."
#endIf
